@@ -35,8 +35,12 @@
     n <- .AddVar(storage.option, varFolder, basename(varnm), storage=storage)
     .append_gds(n, flist, varnm, verbose)
     .DigestCode(n, digest, verbose)
-    if (nVariant != objdesp.gdsn(n)$dim)
-        stop(sprintf("Invalid number of variants in '%s'.", varnm))
+    dm <- objdesp.gdsn(n)$dim
+    if (length(dm)!=1L || nVariant!=dm)
+    {
+        stop(sprintf("Invalid number of variants in '%s' (%s).", varnm,
+            paste(dm, collapse="x")))
+    }
     n
 }
 
@@ -319,7 +323,7 @@ seqMerge <- function(gds.fn, out.fn, storage.option="LZMA_RA",
             nVariant <- nVariant + objdesp.gdsn(index.gdsn(f, "variant.id"))$dim
         }
     } else {
-        variant.id <- variant2.id <- seqGetData(flist[[1L]], "$chrom_pos2")
+        variant.id <- variant2.id <- seqGetData(flist[[1L]], "$chrom_pos_allele")
         if (verbose)
         {
             cat(sprintf("    [%-2d] %s (%s variant%s)\n", 1L, basename(gds.fn[1L]),
@@ -327,7 +331,7 @@ seqMerge <- function(gds.fn, out.fn, storage.option="LZMA_RA",
         }
         for (i in seq_along(flist)[-1L])
         {
-            s <- seqGetData(flist[[i]], "$chrom_pos2")
+            s <- seqGetData(flist[[i]], "$chrom_pos_allele")
             if (verbose)
             {
                 cat(sprintf("    [%-2d] %s (%s variant%s)\n", i,
@@ -366,7 +370,7 @@ seqMerge <- function(gds.fn, out.fn, storage.option="LZMA_RA",
         varidx <- vector("list", length(flist))
         for (i in seq_along(flist))
         {
-            varidx[[i]] <- match(seqGetData(flist[[i]], "$chrom_pos2"),
+            varidx[[i]] <- match(seqGetData(flist[[i]], "$chrom_pos_allele"),
                 variant.id)
             if (is.unsorted(varidx[[i]], strictly=TRUE))
                 stop("File ", i, ": chromosomes and positions are unsorted.")
